# PySAGAS Optimisation Wrappers

```{eval-rst}
.. autoclass:: pysagas.optimisation.optimiser.ShapeOpt
   :members:
```


## Supported Optimisation Wrappers
The following `ShapeOpt` wrappers have been implemented into *PySAGAS*.

```{toctree}
:maxdepth: 2

cart3d
```
